@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmedian.c,v 1.74 2011/07/08 21:27:04 guru Exp $
+ *    $Id: blockmedian.c 10014 2013-04-14 00:57:05Z pwessel $
  *
- *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -48,11 +48,11 @@
 int main (int argc, char **argv)
 {
 
-	GMT_LONG	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, box_and_whisker = FALSE;
+	GMT_LONG	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, box_and_whisker = FALSE, duplicate_col;
 
 	FILE *fp = NULL;
 
-	double	*in = NULL, out[7], wesn[4], quantile[3] = {0.25, 0.5, 0.75}, extra[3], weight, *z_tmp = NULL;
+	double	*in = NULL, out[7], wesn[4], quantile[3] = {0.25, 0.5, 0.75}, extra[3], weight, half_dx, *z_tmp = NULL;
 
 	GMT_LONG	i, ix, iy, fno, n_files = 0, n_args, n_req, w_col;
 	GMT_LONG	n_expected_fields, n_fields, n_out, n_quantiles = 1, go_quickly = 0;
@@ -62,7 +62,7 @@ int main (int argc, char **argv)
 	GMT_LONG	first_in_cell, first_in_new_cell;
 	GMT_LONG	n_alloc = 0, nz_alloc = 0, n_pitched;
 	
-	char	modifier, buffer[BUFSIZ], format[BUFSIZ], *not_used = NULL;
+	char	modifier, buffer[BUFSIZ], format[BUFSIZ];
 
 	struct GRD_HEADER h;
 
@@ -149,7 +149,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "blockmedian %s - Block averaging by L1 norm\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: blockmedian [infile(s)] %s %s\n", GMT_I_OPT, GMT_Rgeo_OPT);
-		fprintf (stderr, "\t[-C] [-E] [-F] [%s] [-Q] [-T<q>] [-V] [-W[i][o] ] [%s] [%s]\n", GMT_H_OPT, GMT_t_OPT, GMT_b_OPT);
+		fprintf (stderr, "\t[-C] [-E[b]] [-F] [%s] [-Q] [-T<q>] [-V] [-W[i][o] ] [%s] [%s]\n", GMT_H_OPT, GMT_t_OPT, GMT_b_OPT);
 		fprintf (stderr, "\t[%s]\n\n", GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
@@ -157,14 +157,14 @@ int main (int argc, char **argv)
 		GMT_inc_syntax ('I', 0);
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "\t-C Output center of block as location  [Default is (median x, median y), but see -Q]\n");
-		fprintf (stderr, "\t-E Extend output with L1 scale (s), low (l), and high (h) value per block, i,e,\n");
+		fprintf (stderr, "\t-C Output center of block as location [Default is (median x, median y), but see -Q].\n");
+		fprintf (stderr, "\t-E Extend output with L1 scale (s), low (l), and high (h) value per block, i.e.,\n");
 		fprintf (stderr, "\t   output (x,y,z,s,l,h[,w]) [Default outputs (x,y,z[,w]); see -W regarding w.\n");
 		fprintf (stderr, "\t   Use -Eb for box-and-whisker output (x,y,z,l,25%%q,75%%q,h[,w])\n");
-		fprintf (stderr, "\t-F Offsets registration so block edges are on gridlines (pixel reg.).  [Default: grid reg.]\n");
+		fprintf (stderr, "\t-F Offsets registration so block edges are on gridlines (pixel reg.) [Default: grid reg.].\n");
 		GMT_explain_option ('H');
-		fprintf (stderr, "\t-Q Quicker; get median z and x,y at that z.  [Default gets median x, median y, median z.]\n");
-		fprintf (stderr, "\t-T Set quantile (0 < q < 1) to report [Default is 0.5 which is the median of z]\n");
+		fprintf (stderr, "\t-Q Quicker; get median z and x,y at that z [Default gets median x, median y, median z].\n");
+		fprintf (stderr, "\t-T Set quantile (0 < q < 1) to report [Default is 0.5 which is the median of z].\n");
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W sets Weight options.\n");
 		fprintf (stderr, "\t   -Wi reads Weighted Input (4 cols: x,y,z,w) but skips w on output.\n");
@@ -227,6 +227,8 @@ int main (int argc, char **argv)
 	h.node_offset = (int)Ctrl->F.active;
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
 
+	duplicate_col = (GMT_360_RANGE (h.x_min, h.x_max) && h.node_offset == 0);	/* E.g., lon = 0 column should match lon = 360 column */
+	half_dx = 0.5 * h.x_inc;
 	go_quickly = (Ctrl->Q.active) ? 1 : 0;	
 	if (Ctrl->C.active) go_quickly = 2;	/* Flag used in output calculation */
 	if (Ctrl->E.active && Ctrl->E.mode == 1) {
@@ -276,7 +278,7 @@ int main (int argc, char **argv)
 
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
-				not_used = GMT_fgets (buffer, BUFSIZ, fp);
+				GMT_fgets (buffer, BUFSIZ, fp);
 				GMT_chop (buffer);
 				if (first && GMT_io.io_header[GMT_OUT]) {
 					(Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? sprintf (format, "%s weights\n", buffer) : sprintf (format, "%s\n", buffer);
@@ -299,6 +301,9 @@ int main (int argc, char **argv)
 
 			if (GMT_y_is_outside (in[GMT_Y],  wesn[2], wesn[3])) continue;	/* Outside y-range */
 			if (GMT_x_is_outside (&in[GMT_X], wesn[0], wesn[1])) continue;	/* Outside x-range */
+			if (duplicate_col && (wesn[1]-in[GMT_X] < half_dx)) {	/* Only compute mean values for the west column and not the repeating east column with lon += 360 */
+				in[GMT_X] -= 360.0;	/* Make this point be considered for the western block mean value */
+			}
 
 			ix = GMT_x_to_i (in[GMT_X], h.x_min, h.x_inc, h.xy_off, h.nx);
 			if ( ix < 0 || ix >= h.nx ) continue;
