@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmode.c,v 1.73 2011/07/08 21:27:05 guru Exp $
+ *    $Id: blockmode.c 10014 2013-04-14 00:57:05Z pwessel $
  *
- *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -42,13 +42,13 @@
 
 int main (int argc, char **argv)
 {
-	GMT_LONG	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, mode_xy;
+	GMT_LONG	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, mode_xy, duplicate_col;
 
 	/* Default value for go_quickly = FALSE for backward compatibility with 3.0  */
 
 	FILE *fp = NULL;
 
-	double	*in = NULL, out[7], wesn[4], i_n_in_cell, weight, *z_tmp = NULL;
+	double	*in = NULL, out[7], wesn[4], i_n_in_cell, weight, half_dx, *z_tmp = NULL;
 
 	GMT_LONG i, j, ix, iy, fno, n_files = 0, n_args, n_req;
 	GMT_LONG n_expected_fields, n_fields, n_out, w_col;
@@ -56,7 +56,7 @@ int main (int argc, char **argv)
 	GMT_LONG n_cells_filled, n_in_cell, nz;
 	GMT_LONG n_alloc = 0, nz_alloc = 0, n_pitched;
 
-	char	modifier, buffer[BUFSIZ], format[BUFSIZ], *not_used = NULL;
+	char	modifier, buffer[BUFSIZ], format[BUFSIZ];
 
 	struct GRD_HEADER h;
 	struct BLK_DATA *data = NULL;
@@ -144,12 +144,12 @@ int main (int argc, char **argv)
 		GMT_inc_syntax ('I', 0);
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "\t-C Output center of block and mode z-value  [Default is mode location (but see -Q)]\n");
-		fprintf (stderr, "\t-E Extend output with LMS scale (s), low (l), and high (h) value per block, i,e,\n");
+		fprintf (stderr, "\t-C Output center of block and mode z-value [Default is mode location (but see -Q)].\n");
+		fprintf (stderr, "\t-E Extend output with LMS scale (s), low (l), and high (h) value per block, i.e.,\n");
 		fprintf (stderr, "\t   output (x,y,z,s,l,h[,w]) [Default outputs (x,y,z[,w]); see -W regarding w.\n");
-		fprintf (stderr, "\t-F Offsets registration so block edges are on gridlines (pixel reg.).  [Default: grid reg.]\n");
+		fprintf (stderr, "\t-F Offsets registration so block edges are on gridlines (pixel reg.) [Default: grid reg.].\n");
 		GMT_explain_option ('H');
-		fprintf (stderr, "\t-Q Quicker; get mode z and mean x,y.  [Default gets mode x, mode y, mode z.]\n");
+		fprintf (stderr, "\t-Q Quicker; get mode z and mean x,y [Default gets mode x, mode y, mode z].\n");
 		GMT_explain_option ('V');
 		fprintf (stderr, "\t-W sets Weight options.\n");
 		fprintf (stderr, "\t   -Wi reads Weighted Input (4 cols: x,y,z,w) but writes only (x,y,z[,s,l,h]) Output.\n");
@@ -208,6 +208,8 @@ int main (int argc, char **argv)
 	h.node_offset = (int)Ctrl->F.active;
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
 	h.xy_off = 0.5 * h.node_offset;	/* Use to calculate mean location of block */
+	duplicate_col = (GMT_360_RANGE (h.x_min, h.x_max) && h.node_offset == 0);	/* E.g., lon = 0 column should match lon = 360 column */
+	half_dx = 0.5 * h.x_inc;
 
 	if (gmtdefs.verbose) {
 		sprintf (format, "%%s: W: %s E: %s S: %s N: %s nx: %%ld ny: %%ld\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
@@ -247,7 +249,7 @@ int main (int argc, char **argv)
 
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
-				not_used = GMT_fgets (buffer, BUFSIZ, fp);
+				GMT_fgets (buffer, BUFSIZ, fp);
 				GMT_chop (buffer);
 				if (first && GMT_io.io_header[GMT_OUT]) {
 					(Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? sprintf (format, "%s weights\n", buffer) : sprintf (format, "%s\n", buffer);
@@ -270,6 +272,9 @@ int main (int argc, char **argv)
 
 			if (GMT_y_is_outside (in[GMT_Y],  wesn[2], wesn[3])) continue;	/* Outside y-range */
 			if (GMT_x_is_outside (&in[GMT_X], wesn[0], wesn[1])) continue;	/* Outside x-range */
+			if (duplicate_col && (wesn[1]-in[GMT_X] < half_dx)) {	/* Only compute mean values for the west column and not the repeating east column with lon += 360 */
+				in[GMT_X] -= 360.0;	/* Make this point be considered for the western block mean value */
+			}
 
 			ix = GMT_x_to_i (in[GMT_X], h.x_min, h.x_inc, h.xy_off, h.nx);
 			if ( ix < 0 || ix >= h.nx ) continue;
