@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c,v 1.145 2011/07/11 19:22:04 guru Exp $
+ *	$Id: mgd77manage.c 9989 2013-03-04 19:14:06Z pwessel $
  *
- *    Copyright (c) 2005-2011 by P. Wessel
+ *    Copyright (c) 2005-2013 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
@@ -74,7 +74,7 @@ int main (int argc, char **argv)
 	
 	float *f = NULL;
 
-	double threshold = 1.0, i_dx = 0, i_dy = 0, x, y, match_value, single_val, dist_scale = 1.0;
+	double threshold = 1.0, x, y, match_value, single_val, dist_scale = 1.0;
 	double parameters[N_PAR], *xtmp, *coldnt = NULL, *colvalue = VNULL, *in = NULL, limits[2];
 
 	struct MGD77_CONTROL In;
@@ -92,8 +92,6 @@ int main (int argc, char **argv)
 	GMT_LONG got_default_answer (char *line, char *answer);
 
 	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
-	GMT_get_time_system ("unix", &(gmtdefs.time_system));						/* MGD77+ uses GMT's Unix time epoch */
-	GMT_init_time_system_structure (&(gmtdefs.time_system));
 	
 	GMT_boundcond_init (&edgeinfo);
 	parameters[COL_SCALE]   = 1.0;	/* Output column scaling */
@@ -579,11 +577,6 @@ int main (int argc, char **argv)
 		if (two_cols) coldnt = (double *) GMT_memory ((void *)coldnt, (size_t)n, sizeof (double), GMT_program);
 	}
 	
-	if (got_grid) {	/* Set inverse spacing */
-		i_dx = 1.0 / grd.x_inc;
-		i_dy = 1.0 / grd.y_inc;
-	}
-
 	MGD77_Ignore_Format (MGD77_FORMAT_ANY);	/* Reset to all formats OK, then ... */
 	MGD77_Ignore_Format (MGD77_FORMAT_M77);	/* disallow ASCII MGD77 files */
 	MGD77_Ignore_Format (MGD77_FORMAT_TBL);	/* and ASCII tables */
@@ -624,7 +617,7 @@ int main (int argc, char **argv)
 		}
 
 		if (delete) {	/* Must create a new file with everything except the fields to be deleted */
-			GMT_LONG id, c;
+			GMT_LONG id, c, reset_column = FALSE;
 			char oldfile[BUFSIZ];
 			
 			if (column != MGD77_NOT_SET) {	/* Get info about this existing column to see if it is compatible with new data */
@@ -661,6 +654,9 @@ int main (int argc, char **argv)
 				strcat (history, " ");
 				strcat (history, p);
 				n_delete++;
+				if (k == column && c == set) {	/* Just removed the old column by the same name, must unset column */
+					reset_column = TRUE;
+				}
 			}
 			
 			/* Rename the old file for now */
@@ -703,7 +699,10 @@ int main (int argc, char **argv)
 				fprintf (stderr, "%s: Error reading data set for cruise %s\n", GMT_program, list[argno]);
 				exit (EXIT_FAILURE);
 			}
-			n_changed++;
+			if (reset_column)
+				column = MGD77_NOT_SET;
+			else
+				n_changed++;
 		}
 
 		if (got_c == ADD_IGRF) {	/* Append IGRF column */
