@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psmask.c,v 1.96 2011/07/08 21:27:06 guru Exp $
+ *	$Id: psmask.c 10085 2013-09-14 06:10:21Z pwessel $
  *
- *	Copyright (c) 1991-2011 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2013 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -90,7 +90,7 @@ int main (int argc, char **argv)
 	GMT_LONG section, n_fields, distance_flag = 0, n_plus = 0, k;
 	GMT_LONG error = FALSE, first = TRUE, node_only;
 
-	char line[BUFSIZ], *grd = NULL, *not_used = NULL;
+	char line[BUFSIZ], *grd = NULL;
 
 	double *in = NULL, distance, x0, y0, x1, y1, shrink = 1.0;
 	double xinc2, yinc2, *x = NULL, *y = NULL;
@@ -106,7 +106,7 @@ int main (int argc, char **argv)
 #endif
 	void draw_clip_contours (double *xx, double *yy, GMT_LONG nn, int rgb[], GMT_LONG id, GMT_LONG flag);
 	void dump_clip_contours (struct PSMASK_INFO *info, double *xx, double *yy, GMT_LONG nn, GMT_LONG id, char *file);
-	void shrink_clip_contours (double *x, double *y, GMT_LONG n, double w, double e);
+	void shrink_clip_contours (double *x, double *y, GMT_LONG np, double w, double e, double s, double n);
 	GMT_LONG clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *h, double xinc2, double yinc2, GMT_LONG *edge, GMT_LONG first, double **x, double **y, GMT_LONG *max);
 	void *New_psmask_Ctrl (), Free_psmask_Ctrl (struct PSMASK_CTRL *C);
 	
@@ -230,34 +230,34 @@ int main (int argc, char **argv)
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
-		fprintf (stderr, "\t<xyz-file> is the datafile.  If not given, read standard input\n");
+		fprintf (stderr, "\t<xyz-file> is the datafile.  If not given, read standard input.\n");
 		GMT_inc_syntax ('I', 0);
 		GMT_explain_option ('j');
 		GMT_explain_option ('R');
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		GMT_explain_option ('b');
-		fprintf (stderr, "\t-C means stop existing clip-path.  No other options required\n");
-		fprintf (stderr, "\t-D dumps the clip-paths to files using the prefix <file>_ [mask_]\n");
+		fprintf (stderr, "\t-C means stop existing clip-path.  No other options required.\n");
+		fprintf (stderr, "\t-D dumps the clip-paths to files using the prefix <file>_ [mask_].\n");
 		fprintf (stderr, "\t   Ignored if -T is specified.  If prefix begins with - we will instead\n");
 		fprintf (stderr, "\t   use the rest of the name for a single multi-segment file.\n");
 		fprintf (stderr, "\t   Append +n<n_pts> to limit the number of points in files to a minimum of n_pts.\n");
 		GMT_explain_option ('E');
-		fprintf (stderr, "\t-F Force pixel registration [Default is gridline registration]\n");
+		fprintf (stderr, "\t-F Force pixel registration [Default is gridline registration].\n");
 		GMT_fill_syntax ('G', "Select fill color/pattern [Default is no fill].");
 		GMT_explain_option ('H');
 		GMT_explain_option ('K');
-		fprintf (stderr, "\t-N will invert the sense of the clipping [or tiling]\n");
+		fprintf (stderr, "\t-N will invert the sense of the clipping [or tiling].\n");
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-S sets search radius in -R, -I units; append m or c for minutes or seconds.\n");
 		fprintf (stderr, "\t   This means nodes inside circles of <radius> centered on\n");
-		fprintf (stderr, "\t   the input data points are considered to be reliable estimates of the surface\n");
-		fprintf (stderr, "\t   Default is -S0, i.e., only the nearest node is considered reliable\n");
+		fprintf (stderr, "\t   the input data points are considered to be reliable estimates of the surface.\n");
+		fprintf (stderr, "\t   Default is -S0, i.e., only the nearest node is considered reliable.\n");
 		fprintf (stderr, "\t   Append k for km (implies -R,-I in degrees), use flat Earth approximation.\n");
 		fprintf (stderr, "\t   Append K for km (implies -R,-I in degrees), use exact geodesic distances.\n");
 		fprintf (stderr, "\t   If the current ELLIPSOID is spherical then great circle distances are used.\n");
-		fprintf (stderr, "\t-T will paint tiles.  [Default will trace data outline]\n");
-		fprintf (stderr, "\t   If set you must also specify a color/fill with -G\n");
+		fprintf (stderr, "\t-T will paint tiles.  [Default will trace data outline].\n");
+		fprintf (stderr, "\t   If set you must also specify a color/fill with -G.\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
 		GMT_explain_option ('X');
@@ -265,7 +265,7 @@ int main (int argc, char **argv)
 		GMT_explain_option (':');
 		GMT_explain_option ('i');
 		GMT_explain_option ('n');
-		fprintf (stderr, "\t   Default is 2 input columns\n");
+		fprintf (stderr, "\t   Default is 2 input columns.\n");
 		GMT_explain_option ('o');
 		GMT_explain_option ('n');
 		GMT_explain_option ('m');
@@ -403,7 +403,7 @@ int main (int argc, char **argv)
 #endif
 		}
 
-		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) not_used = GMT_fgets (line, BUFSIZ, fp);
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
 
 		n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : 2;
 		n_read = 0;
@@ -488,11 +488,12 @@ int main (int argc, char **argv)
 			GMT_map_basemap ();
 
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Tracing the clip path\n", GMT_program);
+			if (Ctrl->D.active && Ctrl->D.file[0] == '-') GMT_io.multi_segments[GMT_OUT] = 1;	/* Write multi-segment files */
 
 			section = 0;
 			first = TRUE;
 			while ((n = clip_contours (&info, grd, &h, xinc2, yinc2, edge, first, &x, &y, &n_alloc)) > 0) {
-				shrink_clip_contours (x, y, n, h.x_min, h.x_max);
+				shrink_clip_contours (x, y, n, h.x_min, h.x_max, h.y_min, h.y_max);
 				if (Ctrl->D.active && n > Ctrl->D.min_pts) dump_clip_contours (&info, x, y, n, section, Ctrl->D.file);
 				draw_clip_contours (x, y, n, Ctrl->G.fill.rgb, section, first);
 				first = FALSE;
@@ -516,7 +517,7 @@ int main (int argc, char **argv)
 				grd_y = GMT_j_to_y (j, h.y_min, h.y_max, h.y_inc, h.xy_off, h.ny);
 				y_bot = grd_y - yinc2;
 				y_top = grd_y + yinc2;
-				ij = GMT_IJ (j, 1, h.nx);
+				ij = GMT_IJ (j, 0, h.nx);
 				for (i = 0; i < h.nx; i++, ij++) {
 					if (((GMT_LONG)grd[ij]) == 0) continue;
 
@@ -680,7 +681,7 @@ GMT_LONG clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *
 				edge_bit = (GMT_LONG)(ij % 32);
 				if (!(edge[edge_word] & info->bit[edge_bit]) && ((grd[ij]+grd[ij-h->nx]) == 1)) { /* Start tracing contour */
 					*x[0] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);
-					*y[0] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
+					*y[0] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny) + 0.5 * h->y_inc;
 					edge[edge_word] |= info->bit[edge_bit];
 					n = trace_clip_contours (info, grd, edge, h, xinc2, yinc2, x, y, i, j, 3, max);
 					go_on = FALSE;
@@ -700,10 +701,11 @@ GMT_LONG clip_contours (struct PSMASK_INFO *info, char *grd, struct GRD_HEADER *
 		for (j = j0; go_on && j < h->ny; j++) {
 			ij = GMT_IJ (j, i0, h->nx);
 			for (i = i0; go_on && i < h->nx-1; i++, ij++) {
-				edge_word = (GMT_LONG)(ij / 32 + info->offset);
+				// edge_word = (GMT_LONG)(ij / 32 + info->offset);
+				edge_word = (GMT_LONG)(ij / 32);
 				edge_bit = (GMT_LONG)(ij % 32);
 				if (!(edge[edge_word] & info->bit[edge_bit]) && ((grd[ij]+grd[ij+1]) == 1)) { /* Start tracing contour */
-					*x[0] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx);
+					*x[0] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, h->xy_off, h->nx) + 0.5 * h->x_inc;
 					*y[0] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, h->xy_off, h->ny);
 					edge[edge_word] |= info->bit[edge_bit];
 					n = trace_clip_contours (info, grd, edge, h, xinc2, yinc2, x, y, i, j, 2, max);
@@ -780,8 +782,8 @@ GMT_LONG trace_clip_contours (struct PSMASK_INFO *info, char *grd, GMT_LONG *edg
 		}
 
 		if (n > m) {	/* Must try to allocate more memory */
-			*max = (*max == 0) ? GMT_CHUNK : ((*max) << 1);
-			m = (m == 0) ? GMT_CHUNK : (m << 1);
+			*max <<= 1;	/* Double the memory */
+			m = *max - 2;	/* But still check for 2 less in case we add 2 points */
 			*xx = (double *) GMT_memory ((void *)*xx, (size_t)(*max), sizeof (double), "trace_clip_contours");
 			*yy = (double *) GMT_memory ((void *)*yy, (size_t)(*max), sizeof (double), "trace_clip_contours");
 		}
@@ -843,20 +845,20 @@ GMT_LONG trace_clip_contours (struct PSMASK_INFO *info, char *grd, GMT_LONG *edg
 	return (n);
 }
 
-void shrink_clip_contours (double *x, double *y, GMT_LONG n, double w, double e)
+void shrink_clip_contours (double *x, double *y, GMT_LONG np, double w, double e, double s, double n)
 {
 	/* Moves outside points to boundary */
 	GMT_LONG i;
 
-	for (i = 0; i < n; i++) {
+	for (i = 0; i < np; i++) {
 		if (x[i] < w)
 			x[i] = w;
 		if (x[i] > e)
 			x[i] = e;
-		if (y[i] < project_info.s)
-			y[i] = project_info.s;
-		if (y[i] > project_info.n)
-			y[i] = project_info.n;
+		if (y[i] < s)
+			y[i] = s;
+		if (y[i] > n)
+			y[i] = n;
 	}
 }
 
