@@ -2,10 +2,10 @@
 #ifndef _controls_
 #define _controls_
 
-extern Widget	createControlBar ();
+extern Widget	createControlBar (String name, Widget parent, Arg args[], int nargs);
 		/* String name, Widget parent, Arg args[], int nargs */
 
-extern void addQuitCallback ();
+extern void addQuitCallback (XtCallbackProc callback, void * clientData);
 		/* XtCallbackProc callback, void * clientData */
 
 #endif
